pub struct IbcOutgoingProxyMsg {
pub collection: String,
pub msg: Binary,
}Fields
collection: Stringmsg: BinaryTrait Implementations
Sourceimpl Clone for IbcOutgoingProxyMsg
impl Clone for IbcOutgoingProxyMsg
Sourcefn clone(&self) -> IbcOutgoingProxyMsg
fn clone(&self) -> IbcOutgoingProxyMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IbcOutgoingProxyMsg
impl Debug for IbcOutgoingProxyMsg
Sourceimpl<'de> Deserialize<'de> for IbcOutgoingProxyMsg
impl<'de> Deserialize<'de> for IbcOutgoingProxyMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IbcOutgoingProxyMsg
impl JsonSchema for IbcOutgoingProxyMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IbcOutgoingProxyMsg
impl PartialEq for IbcOutgoingProxyMsg
Sourcefn eq(&self, other: &IbcOutgoingProxyMsg) -> bool
fn eq(&self, other: &IbcOutgoingProxyMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IbcOutgoingProxyMsg
impl Serialize for IbcOutgoingProxyMsg
impl StructuralPartialEq for IbcOutgoingProxyMsg