pub struct ClassToken {
pub class_id: ClassId,
pub token_id: TokenId,
}Fields
class_id: ClassIdtoken_id: TokenIdTrait Implementations
Sourceimpl Clone for ClassToken
impl Clone for ClassToken
Sourcefn clone(&self) -> ClassToken
fn clone(&self) -> ClassToken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassToken
impl Debug for ClassToken
Sourceimpl<'de> Deserialize<'de> for ClassToken
impl<'de> Deserialize<'de> for ClassToken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClassToken
impl JsonSchema for ClassToken
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClassToken
impl PartialEq for ClassToken
Sourcefn eq(&self, other: &ClassToken) -> bool
fn eq(&self, other: &ClassToken) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ClassToken
impl Serialize for ClassToken
impl StructuralPartialEq for ClassToken