pub struct Ics721Callbacks {
pub ack_callback_data: Option<Binary>,
pub ack_callback_addr: Option<String>,
pub receive_callback_data: Option<Binary>,
pub receive_callback_addr: Option<String>,
}Expand description
The format we expect for the memo field on a send
Fields
ack_callback_data: Option<Binary>Data to pass with a callback on source side (status update) Note - If this field is empty, no callback will be sent
ack_callback_addr: Option<String>The address that will receive the callback message Defaults to the sender address
receive_callback_data: Option<Binary>Data to pass with a callback on the destination side (ReceiveNftIcs721) Note - If this field is empty, no callback will be sent
receive_callback_addr: Option<String>The address that will receive the callback message Defaults to the receiver address