pub struct Ics721ReceiveCallbackMsg {
pub nft_contract: String,
pub original_packet: NonFungibleTokenPacketData,
pub msg: Binary,
}Expand description
A message is that is being called on receiving the NFT after transfer was completed. Receiving this message means that the NFT was successfully transferred. You must verify this message was called by an approved ICS721 contract, either by code_id or address.
Fields
nft_contract: Stringoriginal_packet: NonFungibleTokenPacketDatamsg: BinaryTrait Implementations
Sourceimpl Clone for Ics721ReceiveCallbackMsg
impl Clone for Ics721ReceiveCallbackMsg
Sourcefn clone(&self) -> Ics721ReceiveCallbackMsg
fn clone(&self) -> Ics721ReceiveCallbackMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Ics721ReceiveCallbackMsg
impl Debug for Ics721ReceiveCallbackMsg
Sourceimpl<'de> Deserialize<'de> for Ics721ReceiveCallbackMsg
impl<'de> Deserialize<'de> for Ics721ReceiveCallbackMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Ics721ReceiveCallbackMsg
impl JsonSchema for Ics721ReceiveCallbackMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Ics721ReceiveCallbackMsg
impl PartialEq for Ics721ReceiveCallbackMsg
Sourcefn eq(&self, other: &Ics721ReceiveCallbackMsg) -> bool
fn eq(&self, other: &Ics721ReceiveCallbackMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Ics721ReceiveCallbackMsg
impl Serialize for Ics721ReceiveCallbackMsg
impl StructuralPartialEq for Ics721ReceiveCallbackMsg